# Security Policy

## Supported Versions

| Version   | Supported          |
| --------- | ------------------ |
| 0.1.x     | :white_check_mark: |
| < 0.1.x   | :x:                |

## Reporting a Vulnerability

If you get to find a vulnerability, you have two choices based on the danger which is caused by it.
If you understand by yourself that the vulnerability might cause a lot of danger and may cause destructive actions, **do not open an issue and contact immediately** [Hearot](https://github.com/hearot) via gabriel@hearot.it.
Otherwise, it is recommended to open an issue using the *Bug report* template.
